[Python-checkins] r88906 - tracker/instances/python-dev/html/issue.item.js

ezio.melotti python-checkins at python.org
Sat Oct 8 11:21:58 CEST 2011


Author: ezio.melotti
Date: Sat Oct  8 11:21:58 2011
New Revision: 88906

Log:
#422: do nothing if the meta key is pressed.

Modified:
   tracker/instances/python-dev/html/issue.item.js

Modified: tracker/instances/python-dev/html/issue.item.js
==============================================================================
--- tracker/instances/python-dev/html/issue.item.js	(original)
+++ tracker/instances/python-dev/html/issue.item.js	Sat Oct  8 11:21:58 2011
@@ -77,8 +77,8 @@
     // start from -1 so 'n' sends to the first message at the beginning
     var current = -1;
     $(document).keydown(function (event) {
-        // do nothing if ctrl/alt/shift are pressed
-        if (event.ctrlKey || event.altKey || event.shiftKey)
+        // do nothing if ctrl/alt/shift/meta are pressed
+        if (event.ctrlKey || event.altKey || event.shiftKey || event.metaKey)
             return true;
 
         // disable the shortcuts while editing form elements (except ESC)


More information about the Python-checkins mailing list